# Stat-o-Matic


## How to use it?

1. `pipx install stata-o-matic`
2. create a config file `~/.config/stat_o_matic/config.ini`
 A sample config file is added here
```ini
[STATA]
path=/Applications/Stata/StataMP.app/Contents/MacOS/stata-mp
```
3. run `construct` in your terminal


